2 ms·
Python Performance: Why 'if not list' is 2x Faster Than Using len()
- zahlman 2y ago> But this isn’t just about coding style, one of these is ~2x faster than the other, see for yourself: FWIW, it's not necessary to start an interpreter for this test. $ py3.13 -m timeit --setup "l = []" "not l" 10000000 loops, best of 5: 20.7 nsec per loop $ py3.13 -m timeit --setup "l = []" "len(l) == 0" 10000000 loops, best of 5: 31 nsec per loop
- odie5533 2y agoThe explanation is paywalled. > This post is for paid subscribers.